/* TODO: One CSS file, organize it! */

:root {
  --progwidth: 0%;
}

@font-face{
  font-family:Futura;
  src: url("Futura.ttf");
}

*{
  font-family: Futura;
}

body {
  display:grid;
  grid-template-rows: 10% 75% 15%;
  background-color: black;
  color: white;
}

.top-cols {
  display:grid;
  grid-template-columns: 33% 34% 33%;
  border-bottom: solid;
  font-size: 20px;
  padding-bottom: 5px;
}

.time-result {
  text-align: center;
}

#cpu-result{
  text-align: right;
}

.carInfoBtn {
  justify-items: center;
}

#mus-info {
  display:grid;
  grid-template-rows: auto auto auto;
  text-align:center;
  justify-items: center;
  padding-top: 150px;
  font-size: 2em;
}

#top-time {
  align-items: center;
  display: block;
}

#track-info {
  padding-bottom: 30px;
}

#wait-connect {
  display: none;
}

.musicCols {
  display:grid;
  grid-template-columns: 25% 75%;
  grid-auto-rows: minmax(12em, auto);
}

.musicCols > div {
  padding:1em;
}

.controls {
  padding-top: 10px;
  display: flex;
  justify-content: center;
}

.music-btn {
  padding: 10px;
  background: none;
  border: none;
}

.music-btn:active img{
  -webkit-filter: invert(1);
  filter: invert(1);
}

.wait-connect {
  height: 100%;
}

#wait-time{
  font-size: 70px;
}

#wait-msg {
  font-size: 20px;
}

.highlight {
  color: gold;
}

.car-info {
  display: grid;
  grid-template-columns: auto auto auto;
  grid-template-rows: auto auto auto;
  padding-top: 20px;
}

.car-info > div {
  padding: 15px;
  border: 3px;
  border-style: solid;
  border-color: white;
  text-align: center;
}

#main-content {
  display: grid;
  justify-items: center;
}


/* =============
 Tab Buttons/Tab formatting
============= */

.tab {
  display: grid;
  grid-template-columns: 25% 25% 25% 25%;
  justify-items: center;
  padding-bottom: 18px;
  width: 50%;
  position: fixed;
  bottom: 0;
}

.tab button {
  font-size: 1.5em;
  background-color: inherit;
  text-align: center;
  border: none;
  outline: none;
  cursor: pointer;
  width: 100%;
 /* padding: 14px 16px; */
  transition: 0.3s;
}

/* Change background color of buttons on hover */
.tab button:hover, .tab button.active {
  -webkit-filter: invert(1);
  filter: invert(1);
}

/* Style the tab content */
.tab-content {
  display: none;
  padding: 6px 12px;
  border-top: none;
  justify-content: center;
  width: 75%;
} 

/* =============
 Settings
============= */

#Settings > div {
  padding-top: 15px;
  text-align: center;
}

#Settings > div > button {
  background-color: white;
  text-align: center;
  border: none;
  outline: none;
  width: 150px;
  padding: 14px 16px;
  transition: 0.3s;
}

/* =============
 ADB Info
============= */

/* Hide scrollbar on Chrome, Safari and Opera */
#adb-notifs::-webkit-scrollbar {
  display: none;
}

/* Hide scrollbar for IE, Edge and Firefox */
#adb-notifs {
  height: 425px;
  overflow-y: auto;
  scrollbar-width: none; 
  width: 90%;
}

.notification {
  display: grid;
  grid-template-columns: 14% 86%;
  width: 90%;
  height: fit-content;
  min-height: 40px;
  border: solid;
  border-radius: 15px;
  border-color: white;
  margin: 0 auto;
  margin-top: 10px;
}

.notification-img {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 100%;
}

.notification-img > img {
  max-width: 30px;
  max-height: 30px;
}

.notification-text > h3, .notification-text > p {
  margin-top: 5px;
  margin-bottom: 5px;
}
